@@ -1,18 +1,21 @@
 MillerCalib <- function(model = NULL, obs = NULL, pred = NULL, plot = TRUE, line.col = "black", diag = TRUE, diag.col = "grey", plot.values = TRUE, digits = 2, xlab = "", ylab = "", main = "Miller calibration", ...) {
-  # version 1.4 (7 Oct 2018)
+  # version 1.6 (13 Dec 2021)
 
   model.provided <- ifelse(is.null(model), FALSE, TRUE)
 
   if (model.provided) {
-    if(!("glm" %in% class(model) && model$family$family == "binomial" && model$family$link == "logit")) stop ("'model' must be an object of class 'glm' with 'binomial' family and 'logit' link.")
+    #if(!("glm" %in% class(model) && model$family$family == "binomial" && model$family$link == "logit")) stop ("'model' must be an object of class 'glm' with 'binomial' family and 'logit' link.")
     if (!is.null(pred)) message("Argument 'pred' ignored in favour of 'model'.")
     if (!is.null(obs)) message("Argument 'obs' ignored in favour of 'model'.")
-    obs <- model$y
-    pred <- model$fitted.values
-
+    # obs <- model$y
+    # pred <- model$fitted.values
+    obspred <- mod2obspred(model)
+    obs <- obspred[ , "obs"]
+    pred <- obspred[ , "pred"]
+    
   } else { # if model not provided
 
-    if (is.null(obs) | is.null(pred))  stop ("You must provide either 'obs' and 'pred', or a 'model' object of class 'glm'.")
+    if (is.null(obs) | is.null(pred))  stop ("You must provide either 'obs' and 'pred', or a 'model' object.")
     if (length(obs) != length(pred))  stop ("'obs' and 'pred' must have the same number of values (and in the same order).")
     # new (15 Sep 2015):
     dat <- data.frame(obs, pred)
@@ -26,7 +29,7 @@ MillerCalib <- function(model = NULL, obs = NULL, pred = NULL, plot = TRUE, line
 
   stopifnot(
     length(obs) == length(pred),
-    obs %in% c(0,1)#,
+    obs %in% c(0, 1)#,
     #pred >= 0,
     #pred <= 1
   )
@@ -53,12 +56,12 @@ MillerCalib <- function(model = NULL, obs = NULL, pred = NULL, plot = TRUE, line
     if (diag) abline(0, 1, col = diag.col, lty = 2)
     abline(intercept, slope, col = line.col)
     if (plot.values) {
-      #plotext <- paste("intercept =" , round(intercept, digits), "\nslope =", round(slope, digits), "\nslope p-value =", round(slope.p, digits))
-      plotext <- paste0("intercept = " , round(intercept, digits), "\nslope = ", round(slope, digits))
-      text(x = 1, y = ymin + 0.1 * (ymax - ymin), adj = 1, labels = plotext)
+      # plotext <- paste("intercept =" , round(intercept, digits), "\nslope =", round(slope, digits), "\nslope p-value =", round(slope.p, digits))
+      plotext <- paste0("slope = " , round(slope, digits), "\nintercept = ", round(intercept, digits))
+      text(x = 1, y = ymin + 0.15 * (ymax - ymin), adj = 1, labels = plotext)
     }  # end if plot.values
   }  # end if plot
 
-  #return(list(intercept = intercept, slope = slope, slope.pvalue = slope.p))
+  # return(list(intercept = intercept, slope = slope, slope.pvalue = slope.p))
   list(intercept = intercept, slope = slope)
 }  # end MillerCalib function
