@@ -7,27 +7,23 @@ function(a, b, c, d, N = NULL, measure = "CCR"){
   # measure: evaluation measure to use
   # note: TSS and NMI are not symmetrical ("obs" vs "pred" != "pred" vs "obs")
   # note that some measures (e.g. NMI, odds ratio) don't work with zeros in (some parts of) the confusion matrix
-  if(is.null(N))  N <- a + b + c + d
+  if (is.null(N))  N <- a + b + c + d
   stopifnot(N == a + b + c + d)
-  if(measure == "CCR") { value <- (a+d)/N
+  if (measure == "CCR") { value <- (a+d)/N
   } else if(measure %in% c("Sensitivity", "Recall")) { value <- a/(a+c)
   } else if(measure == "Specificity") { value <- d/(b+d)
   } else if(measure == "Omission") { value <- c/(a+c)
   } else if(measure == "Commission") { value <- b/(b+d)
-  } else if(measure %in% c("PPP", "Precision")) { value <- a/(a+b)  # also called "Precision"
+  } else if(measure %in% c("PPP", "Precision")) { value <- a/(a+b)
   } else if(measure == "NPP") { value <- d/(c+d)
   } else if(measure == "Misclass") { value <- (b+c)/N
   } else if(measure == "UPR") { value <- c/(c+d)  # this and next 3: Barbosa et al. 2013 Diversity and Distributions
   } else if(measure == "OPR") { value <- b/(a+b)
   } else if(measure == "PPI") { value <- ((a+b)/(a+c))-1
   } else if(measure == "PAI") { value <- ((c+d)/(b+d))-1
-  } else if(measure == "kappa") { value <- ((a+d)-(((a+c)*(a+b)+(b+d)*(c+d))/N))/
-                                    (N-(((a+c)*(a+b)+(b+d)*(c+d))/N))
+  } else if(measure == "kappa") { value <- ((a+d)-(((a+c)*(a+b)+(b+d)*(c+d))/N))/(N-(((a+c)*(a+b)+(b+d)*(c+d))/N))
   } else if(measure == "TSS") { value <- (a*d - b*c) / ((a+c) * (b+d))
-  } else if(measure == "NMI") { value <- 1-((-a*log(a)-b*log(b)-c*log(c)-d*log(d)
-                                             +(a+b)*log(a+b)+(c+d)*log(c+d))
-                                            /(N*log(N)-((a+c)*log(a+c)
-                                                        +(b+d)*log(b+d))))  # NMI by Forbes (1995); the "1-" was missing in Fielding & Bell 1997 (and Manel et al 2001) but Fielding confirmed it was a typo
+  } else if(measure == "NMI") { value <- 1-((-a*log(a)-b*log(b)-c*log(c)-d*log(d)+(a+b)*log(a+b)+(c+d)*log(c+d))/(N*log(N)-((a+c)*log(a+c)+(b+d)*log(b+d))))  # NMI by Forbes (1995); the "1-" was missing in Fielding & Bell 1997 (and Manel et al 2001) but Fielding confirmed it was a typo
   } else if (measure == "F1score") {
     precision <- a/(a+b)
     recall <- a/(a+c)
